@@ -19,9 +19,7 @@
 expand_grid. <- function(..., .name_repair = "check_unique") {
   dots <- dots_list(..., .named = TRUE)
 
-  cj <- call2_dt("CJ", !!!dots, unique = FALSE, sorted = FALSE)
-
-  result_df <- eval_tidy(cj, env = caller_env())
+  result_df <- exec("CJ", !!!dots, unique = FALSE, sorted = FALSE)
 
   setkey(result_df, NULL)
 
