@@ -86,8 +86,6 @@ pivot_longer..tidytable <- function(.df,
   variable_name <- "variable"
 
   if (uses_dot_value) {
-    .df <- shallow(.df)
-
     if (multiple_names_to && any(na_in_names_to)) {
       names_to[na_in_names_to] <- ".id"
     } else if (!multiple_names_to) {
@@ -103,7 +101,9 @@ pivot_longer..tidytable <- function(.df,
 
       names_glue <- paste0("{", names_to, "}", collapse = "___")
       new_names <- glue_data(names_to_setup, names_glue)
-      setnames(.df, measure_vars, new_names)
+
+      .df <- setnames.(.df, measure_vars, new_names)
+
       measure_vars <- new_names
     } else {
       abort("If you use '.value' in `names_to` you must also supply
@@ -123,7 +123,7 @@ pivot_longer..tidytable <- function(.df,
     na_cols <- setdiff(glued, measure_vars)
 
     if (length(na_cols) > 0) {
-      .df[, (na_cols) := NA]
+      .df <- dt_j(.df, (na_cols) := NA)
     }
 
     .value <- names_to_setup$.value
@@ -156,7 +156,7 @@ pivot_longer..tidytable <- function(.df,
     na_rm <- FALSE
   }
 
-  .df <- suppressWarnings(melt(
+  out <- suppressWarnings(melt(
     data = .df,
     id.vars = id_vars,
     measure.vars = measure_vars,
@@ -169,7 +169,7 @@ pivot_longer..tidytable <- function(.df,
   ))
 
   if (!is.null(names_prefix)) {
-    .df <- mutate.(.df, !!variable_name := gsub(paste0("^", .env$names_prefix), "", !!sym(variable_name)))
+    out <- mutate.(out, !!variable_name := gsub(paste0("^", .env$names_prefix), "", !!sym(variable_name)))
   }
 
   if (multiple_names_to && uses_dot_value) {
@@ -177,29 +177,29 @@ pivot_longer..tidytable <- function(.df,
       .value_ids <- NULL
     }
 
-    .df <- mutate.(.df, !!variable_name := .env$.value_ids)
+    out <- mutate.(out, !!variable_name := .env$.value_ids)
   } else if (multiple_names_to && !uses_dot_value) {
     if (!is.null(names_sep)) {
-      .df <- separate.(.df, !!sym(variable_name), into = names_to, sep = names_sep)
+      out <- separate.(out, !!sym(variable_name), into = names_to, sep = names_sep)
     } else {
-      .df <- extract.(.df, !!sym(variable_name), into = names_to, regex = names_pattern)
+      out <- extract.(out, !!sym(variable_name), into = names_to, regex = names_pattern)
     }
 
     # Put new names before value column
-    .df <- relocate.(.df, !!!syms(names_to), .before = !!sym(values_to))
+    out <- relocate.(out, !!!syms(names_to), .before = !!sym(values_to))
   } else if (!multiple_names_to && uses_dot_value) {
-    .df <- mutate.(.df, variable = NULL)
+    out <- dt_j(out, !!variable_name := NULL)
   }
 
-  .df <- df_name_repair(.df, .name_repair = names_repair)
+  out <- df_name_repair(out, .name_repair = names_repair)
 
   # names_ptype & names_transform
-  .df <- change_types(.df, names_to, names_ptypes, "ptypes")
-  .df <- change_types(.df, names_to, names_transform, "transform")
+  out <- change_types(out, names_to, names_ptypes, "ptypes")
+  out <- change_types(out, names_to, names_transform, "transform")
 
   # values_ptype & values_transform
-  .df <- change_types(.df, values_to, values_ptypes, "ptypes")
-  .df <- change_types(.df, values_to, values_transform, "transform")
+  out <- change_types(out, values_to, values_ptypes, "ptypes")
+  out <- change_types(out, values_to, values_transform, "transform")
 
   # data.table::melt() drops NAs using "&" logic, not "|"
   # Example in tidytable #186 shows why this is necessary
@@ -207,10 +207,10 @@ pivot_longer..tidytable <- function(.df,
     filter_calls <- map.(syms(values_to), ~ call2("!", call2("is.na", .x)))
     filter_expr <- call_reduce(filter_calls, "|")
 
-    .df <- filter.(.df, !!filter_expr)
+    out <- filter.(out, !!filter_expr)
   }
 
-  as_tidytable(.df)
+  as_tidytable(out)
 }
 
 #' @export
@@ -243,18 +243,15 @@ pivot_longer..data.frame <- function(.df,
 
 str_extract <- function(x, into, regex, convert = FALSE) {
   out <- str_extract_groups(x, pattern = regex, convert = convert)
-  out <- as_tidytable(out)
   names(out) <- into
+  out <- new_tidytable(out)
   out
 }
 
 str_separate <- function(x, into, sep, convert = FALSE) {
-  vec_assert(into, character())
-
   out <- data.table::tstrsplit(x, sep, fixed = TRUE, names = TRUE, type.convert = convert)
-  out <- as_tidytable(out)
   names(out) <- as_utf8_character(into)
-
+  out <- new_tidytable(out)
   out
 }
 
