@@ -14,17 +14,15 @@ tidytable <- function(..., .name_repair = c("check_unique", "unique", "universal
   dots <- dots_list(..., .named = TRUE)
 
   if (length(dots) == 0) {
-    df <- data.table()
+    df <- new_tidytable()
   } else {
     dots <- map.(dots, ~ if (is_quosure(.x)) eval_tidy(.x) else .x)
     dots <- dots[!map_lgl.(dots, is.null)]
 
-    df <- vctrs::data_frame(!!!dots, .name_repair = .name_repair)
+    dots <- vec_recycle_common(!!!dots)
 
-    setDT(df)
+    df <- df_name_repair(new_tidytable(dots), .name_repair = .name_repair)
   }
 
-  setattr(df, "class", c("tidytable", "data.table", "data.frame"))
-
   df
 }
