@@ -4,6 +4,45 @@ shallow <- function(x) {
   x[TRUE]
 }
 
+# Copy columns that are being overwritten
+# If columns are all new uses shallow copy
+# Faster than running `copy()` on an entire dataset
+fast_copy <- function(x, new_cols = character()) {
+  if (length(new_cols) == 0) return(shallow(x))
+
+  x_names <- copy(names(x))
+  needs_copy <- new_cols %chin% x_names
+  if (any(needs_copy)) {
+    copy_cols <- new_cols[needs_copy]
+  } else {
+    copy_cols <- character()
+  }
+
+  if (length(copy_cols) == 0) {
+    out <- shallow(x)
+  } else {
+    out <- vector("list", length(x_names))
+    setattr(out, "names", x_names)
+    for (col in x_names) {
+      if (col %chin% copy_cols) {
+        out[[col]] <- copy(x[[col]])
+      } else {
+        out[[col]] <- x[[col]]
+      }
+    }
+    setDT(out)
+    class <- copy(class(x))
+    setattr(out, "class", class)
+  }
+  out[]
+}
+
+# dt call starting with the j position
+dt_j <- function(.df, j, ...) {
+  j <- enquo(j)
+  dt(.df, , !!j, ...)
+}
+
 # Create a call to `[.data.table` (i position)
 call2_i <- function(.df, i = NULL) {
   # Use enquo(.df) to clean up error messages, #305
@@ -11,9 +50,18 @@ call2_i <- function(.df, i = NULL) {
 }
 
 # Create a call to `[.data.table` (j position)
-call2_j <- function(.df, j = NULL, .by = NULL, ...) {
-  dt_expr <- call2("[", enquo(.df), , j, by = .by, ...)
-  call2("[", dt_expr)
+call2_j <- function(.df, j = NULL, .by = NULL, .keyby = NULL, ...) {
+  if (is.null(.keyby)) {
+    dt_expr <- call2("[", enquo(.df), , j, by = .by, ...)
+  } else {
+    dt_expr <- call2("[", enquo(.df), , j, keyby = .keyby, ...)
+  }
+
+  if (is_call(j, c(":=", "let"))) {
+    dt_expr <- call2("[", dt_expr)
+  }
+
+  dt_expr
 }
 
 # Uses fast by trick for i position using .I
@@ -25,19 +73,30 @@ call2_fast_by_i <- function(.df, j, .by) {
   dt_expr
 }
 
+# setnames without modify-by-reference
+setnames. <- function(x, old, new) {
+  x <- shallow(x)
+  setnames(x, old, new)
+}
+
 # Extract environment from quosures to build the evaluation environment
 get_dt_env <- function(x, ...) {
+  .default <- caller_env(2)
   if (length(x) == 0) {
-    dt_env <- caller_env(2)
+    dt_env <- .default
   } else if (is_quosures(x)) {
-    x <- x[[1]]
-    dt_env <- get_env(x)
+    envs <- map.(x, get_env)
+    non_empty <- map_lgl.(envs, ~ !identical(.x, empty_env()))
+    if (any(non_empty)) {
+      dt_env <- envs[non_empty][[1]]
+    } else {
+      dt_env <- .default
+    }
   } else {
     dt_env <- get_env(x)
-  }
-
-  if (identical(dt_env, empty_env())) {
-    dt_env <- caller_env(2)
+    if (identical(dt_env, empty_env())) {
+      dt_env <- .default
+    }
   }
 
   env(dt_env, ...)
@@ -59,40 +118,16 @@ call_reduce <- function(x, fun) {
 
 # radix sort
 # proxy for data.table::fsort since negative values aren't supported, #282
-f_sort <- function(x, decreasing = FALSE, na.last = FALSE) {
-  # # Can switch to data.table::fsort once negative doubles are handled
-  # suppressWarnings(
-  #   fsort(x, decreasing = decreasing, na.last = na.last)
-  # )
-
-  sort(x, decreasing = decreasing, na.last = na.last, method = "radix")
-}
-
-# pmap - for internal use only
-# Taken from: https://github.com/r-lib/rlang/blob/master/R/compat-purrr.R
-pmap. <- function(.l, .f, ...) {
-  .f <- as_function(.f)
-  args <- args_recycle(.l)
-  do.call("mapply", c(
-    FUN = list(quote(.f)),
-    args, MoreArgs = quote(list(...)),
-    SIMPLIFY = FALSE, USE.NAMES = FALSE
-  ))
-}
-
-pmap_chr. <- function(.l, .f, ...) {
-  as.character(pmap.(.l, .f, ...))
-}
-
-args_recycle <- function(args) {
-  lengths <- map_int.(args, length)
-  n <- max(lengths)
-
-  stopifnot(all(lengths == 1L | lengths == n))
-  to_recycle <- lengths == 1L
-  args[to_recycle] <- map.(args[to_recycle], function(x) rep.int(x, n))
-
-  args
+f_sort <- function(x) {
+  # Can switch to data.table::fsort once negative doubles are handled
+  # See: https://github.com/Rdatatable/data.table/issues/5051
+  if (is.character(x)) {
+    suppressWarnings(
+      fsort(x)
+    )
+  } else {
+    vec_sort(x)
+  }
 }
 
 # Restore user defined attributes
@@ -105,7 +140,7 @@ tidytable_restore <- function(x, to) {
 
 deprecate_old_across <- function(fn) {
   .what <- glue("tidytable::{fn}_across.()")
-  .details <- glue("Please use `{fn}.(across.())")
+  .details <- glue("Please use `{fn}.(across.())`")
 
   deprecate_warn("0.6.4", what = .what, details = .details, id = fn)
 }
@@ -129,21 +164,6 @@ change_types <- function(.df, .to, .list, .ptypes_transform) {
   .df
 }
 
-# Internal mutate.(across.())
-# Use when you don't want to repeat tidyselect steps
-# .cols and .by should be character vectors
-mutate_lapply <- function(.df, .cols, fn, ..., .by = character()) {
-  if (length(.by) == 0) {
-    .df <- shallow(.df)
-  } else {
-    copy(.df)
-  }
-
-  .df[, (.cols) := map.(.SD, fn, ...), by = .by, .SDcols = .cols]
-
-  .df
-}
-
 # deprecated shallow() ------------------------------------------------
 # shallow <- function(x, cols = names(x), reset_class = FALSE) {
 #   stopifnot(is.data.table(x), all(cols %in% names(x)))
